```{include} ../README.md
:start-after: '<!-- docs-intro-begin -->'
:end-before: '<!-- docs-intro-end -->'
```

```{include} ../README.md
:start-after: '<!-- docs-content-begin -->'
:end-before: '<!-- docs-content-end -->'
```

```{toctree}
:hidden:
:maxdepth: 3
Naming <naming>
Attributes/Properties <params>
slots
Assets <assets>
Organization <organization>
configuration
```

```{toctree}
:hidden:
:maxdepth: 2
:caption: Project

project/changelog.md
project/motivation.md
project/roadmap.md
```

```{toctree}
:hidden:
:maxdepth: 3
:caption: API Reference

apidocs/django_bird/django_bird.rst
```

```{toctree}
:hidden:
:maxdepth: 2
:caption: Development

development/contributing.md
development/just.md
Releasing <development/releasing.md>
```
